@@ -41,7 +41,7 @@ class SeleniumBrowserUcMiddleware:
     def process_request(self, request, spider):
         """Process a request using the selenium driver if applicable"""
 
-        if not isinstance(request, SeleniumRequest):
+        if not isinstance(request, SeleniumBrowserUcRequest):
             return None
 
         self.driver.get(request.url)
@@ -80,4 +80,4 @@ class SeleniumBrowserUcMiddleware:
     def spider_closed(self):
         """Shutdown the driver when spider is closed"""
 
-        self.driver.quit()
+        self.driver.close_driver()
